@@ -1,8 +1,7 @@
 package CWB::CQP::More::Iterator;
+$CWB::CQP::More::Iterator::VERSION = '0.07';
 use Data::Dumper;
 
-our $VERSION = '0.02';
-
 sub new {
     my ($class, $cwb, $resultset, %ops) = @_;
     return undef unless $resultset && eval { $cwb->isa('CWB::CQP::More') };
@@ -84,7 +83,7 @@ sub _min { $_[0] < $_[1] ? $_[0] : $_[1] }
 sub _max { $_[0] > $_[1] ? $_[0] : $_[1] }
 
 
-$VERSION;
+1;
 
 __END__
 
